
TODO_10_72_28_05: Support `help` for any number of commands.

It also applies to `intercept` and `query_enum`.

The issue is temporarily fixed via `tree_abs_path_to_interp_id` config.
But this fix is cumbersome.

The proper fix should be addressed via FS_33_76_82_84 composite tree.
The change is to use single config place where all interps, delegators, functions are referenced.
Instead of configuring parts of the tree (sub-trees) under different plugins.
It should be made convenient to see the whole picture in single place
(and that tree is used as a config for the plugins).
Think how to encode the tree via YAML for both func ids and interp ids (it seems it should contain both).
